AppProviderObserver class
base
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
didAddProvider(ProviderObserverContext context, Object? value)
→ void
-
A provider was initialized, and the value exposed is
value.
-
didDisposeProvider(ProviderObserverContext context)
→ void
-
A provider was disposed
inherited
-
didUpdateProvider(ProviderObserverContext context, Object? previousValue, Object? newValue)
→ void
-
Called by providers when they emit a notification.
-
mutationError(ProviderObserverContext context, Mutation<Object?> mutation, Object error, StackTrace stackTrace)
→ void
-
A mutation failed.
inherited
-
mutationReset(ProviderObserverContext context, Mutation<Object?> mutation)
→ void
-
A mutation was reset.
inherited
-
mutationStart(ProviderObserverContext context, Mutation<Object?> mutation)
→ void
-
A mutation was started.
inherited
-
mutationSuccess(ProviderObserverContext context, Mutation<Object?> mutation, Object? result)
→ void
-
A mutation succeeded.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
providerDidFail(ProviderObserverContext context, Object error, StackTrace stackTrace)
→ void
-
A provider emitted an error, be it by throwing during initialization
or by having a Future/Stream emit an error
-
toString()
→ String
-
A string representation of this object.
inherited