didUpdateProvider method
void
didUpdateProvider()
Called by providers when they emit a notification.
newValuewill benullif the provider threw during initialization.previousValuewill benullif the previous build threw during initialization. mutation If the change is caused by a "mutation", [] will be the invocation that caused the state change. This includes when a mutation manually callsstate=:
@riverpod
class Example extends _$Example {
@override
int count() => 0;
@mutation
int increment() {
state++; // This will trigger `didUpdateProvider` and "mutation" will be `#increment`
// ...
}
}
Implementation
@override
void didUpdateProvider(
ProviderObserverContext context,
Object? previousValue,
Object? newValue,
) {
_logger.d('Provider ${context.provider.name ?? context.provider.runtimeType} updated\n'
' from: $previousValue\n'
' to: $newValue');
}