SideEffect class sealed
- Available extensions
- Annotations
-
- @freezed
Constructors
- SideEffect.bottomSheet({required Widget builder, @Default.new(true) bool isDismissible})
-
constfactory
- SideEffect.failure({required String title, required String message})
-
constfactory
- SideEffect.info({required String title, required String message})
-
constfactory
- SideEffect.snackBar({required String message, @Default.new(false) bool isError})
-
constfactory
- SideEffect.success({required String title, required String message})
-
constfactory
- SideEffect.warning({required String title, required String message})
-
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> ({required TResult success(_Success value), required TResult failure(_Failure value), required TResult info(_Info value), required TResult warning(_Warning value), required TResult snackBar(_SnackBar value), required TResult bottomSheet(_BottomSheet value)}) → TResult -
Available on SideEffect, provided by the SideEffectPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> ({TResult? success(_Success value)?, TResult? failure(_Failure value)?, TResult? info(_Info value)?, TResult? warning(_Warning value)?, TResult? snackBar(_SnackBar value)?, TResult? bottomSheet(_BottomSheet value)?}) → TResult? -
Available on SideEffect, provided by the SideEffectPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({TResult success(_Success value)?, TResult failure(_Failure value)?, TResult info(_Info value)?, TResult warning(_Warning value)?, TResult snackBar(_SnackBar value)?, TResult bottomSheet(_BottomSheet value)?, required TResult orElse()}) → TResult -
Available on SideEffect, provided by the SideEffectPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({TResult success(String title, String message)?, TResult failure(String title, String message)?, TResult info(String title, String message)?, TResult warning(String title, String message)?, TResult snackBar(String message, bool isError)?, TResult bottomSheet(Widget builder, bool isDismissible)?, required TResult orElse()}) → TResult -
Available on SideEffect, provided by the SideEffectPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> ({required TResult success(String title, String message), required TResult failure(String title, String message), required TResult info(String title, String message), required TResult warning(String title, String message), required TResult snackBar(String message, bool isError), required TResult bottomSheet(Widget builder, bool isDismissible)}) → TResult -
Available on SideEffect, provided by the SideEffectPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> ({TResult? success(String title, String message)?, TResult? failure(String title, String message)?, TResult? info(String title, String message)?, TResult? warning(String title, String message)?, TResult? snackBar(String message, bool isError)?, TResult? bottomSheet(Widget builder, bool isDismissible)?}) → TResult? -
Available on SideEffect, provided by the SideEffectPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited