AppRoute enum
- Inheritance
- Available extensions
Values
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
go(
BuildContext context, {Object? arguments}) → void -
Available on AppRoute, provided by the AppRouteNavigation extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
push(
BuildContext context, {Object? arguments}) → void -
Available on AppRoute, provided by the AppRouteNavigation extension
-
replace(
BuildContext context, {Object? arguments}) → void -
Available on AppRoute, provided by the AppRouteNavigation extension
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited