ApiClient class
Properties
-
dio
→ Dio
-
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get<T>(String path, {Map<String, dynamic>? queryParameters, Options? options, CancelToken? cancelToken})
→ Future<Response<T>>
-
Utility for GET requests
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
post<T>(String path, {dynamic data, Map<String, dynamic>? queryParameters, Options? options, CancelToken? cancelToken})
→ Future<Response<T>>
-
Utility for POST requests
-
toString()
→ String
-
A string representation of this object.
inherited