LoggerService class

Constructors

LoggerService()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionTimeline List<Breadcrumb>
Returns the current session's timeline for crash reporting.
no setter

Methods

clearSession() → void
Clears the session timeline (e.g., on logout).
d(String message, [dynamic data]) → void
e(String message, [dynamic error, StackTrace? stackTrace]) → void
error(String message, [dynamic error, StackTrace? stackTrace]) → void
i(String message, [dynamic data]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
w(String message, [dynamic data]) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited