NavigationService class

Constructors

Properties

context BuildContext?
no setter
hashCode int
The hash code for this object.
no setterinherited
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pop<T>([T? result]) → void
popUntil(bool predicate(Route)) → void
pushNamed<T>(String routeName, {Object? arguments}) Future<T?>
pushNamedAndRemoveUntil<T>(String routeName, bool predicate(Route), {Object? arguments}) Future<T?>
pushReplacementNamed<T, TO>(String routeName, {Object? arguments, TO? result}) Future<T?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited