AppButtonTheme class
- Inheritance
-
- Object
- ThemeExtension<
AppButtonTheme> - AppButtonTheme
Constructors
- AppButtonTheme({ButtonStyle? primary, ButtonStyle? neutral, ButtonStyle? destructive})
Properties
- destructive → ButtonStyle?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- neutral → ButtonStyle?
-
final
- primary → ButtonStyle?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
{ButtonStyle? primary, ButtonStyle? neutral, ButtonStyle? destructive}) → AppButtonTheme -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< AppButtonTheme> ? other, double t) → AppButtonTheme -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited