Todo class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
Properties
-
copyWith
→ $TodoCopyWith<
Todo> -
Create a copy of Todo
with the given fields replaced by the non-null parameter values.
no setterinherited
- description → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setterinherited
- isCompleted → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_Todo value)) → TResult -
Available on Todo, provided by the TodoPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_Todo value)?) → TResult? -
Available on Todo, provided by the TodoPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_Todo value)?, {required TResult orElse()}) → TResult -
Available on Todo, provided by the TodoPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String id, String title, String description, bool isCompleted)?, {required TResult orElse()}) → TResult -
Available on Todo, provided by the TodoPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this Todo to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String id, String title, String description, bool isCompleted)) → TResult -
Available on Todo, provided by the TodoPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String id, String title, String description, bool isCompleted)?) → TResult? -
Available on Todo, provided by the TodoPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited