DetailsUIState class

Available extensions
Annotations
  • @freezed

Constructors

DetailsUIState.error([String? message])
const
factory
DetailsUIState.initial()
const
factory
DetailsUIState.loading()
const
factory
DetailsUIState.success({required Todo todo})
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult initial(_Initial value), required TResult loading(_Loading value), required TResult success(_Success value), required TResult error(_Error value)}) → TResult

Available on DetailsUIState, provided by the DetailsUIStatePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>({TResult? initial(_Initial value)?, TResult? loading(_Loading value)?, TResult? success(_Success value)?, TResult? error(_Error value)?}) → TResult?

Available on DetailsUIState, provided by the DetailsUIStatePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>({TResult initial(_Initial value)?, TResult loading(_Loading value)?, TResult success(_Success value)?, TResult error(_Error value)?, required TResult orElse()}) → TResult

Available on DetailsUIState, provided by the DetailsUIStatePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>({TResult initial()?, TResult loading()?, TResult success(Todo todo)?, TResult error(String? message)?, required TResult orElse()}) → TResult

Available on DetailsUIState, provided by the DetailsUIStatePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult initial(), required TResult loading(), required TResult success(Todo todo), required TResult error(String? message)}) → TResult

Available on DetailsUIState, provided by the DetailsUIStatePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>({TResult? initial()?, TResult? loading()?, TResult? success(Todo todo)?, TResult? error(String? message)?}) → TResult?

Available on DetailsUIState, provided by the DetailsUIStatePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited