HomeUIState class abstract

Available extensions
Annotations
  • @freezed

Constructors

HomeUIState({@Default.new(HomeUIStatus.initial) HomeUIStatus status, @Default.new([]) List<Todo> todos, String? errorMessage})
const
factory

Properties

copyWith → $HomeUIStateCopyWith<HomeUIState>
Create a copy of HomeUIState with the given fields replaced by the non-null parameter values.
no setterinherited
errorMessage String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status HomeUIStatus
no setterinherited
todos List<Todo>
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_HomeUIState value)) → TResult

Available on HomeUIState, provided by the HomeUIStatePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_HomeUIState value)?) → TResult?

Available on HomeUIState, provided by the HomeUIStatePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_HomeUIState value)?, {required TResult orElse()}) → TResult

Available on HomeUIState, provided by the HomeUIStatePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(HomeUIStatus status, List<Todo> todos, String? errorMessage)?, {required TResult orElse()}) → TResult

Available on HomeUIState, provided by the HomeUIStatePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(HomeUIStatus status, List<Todo> todos, String? errorMessage)) → TResult

Available on HomeUIState, provided by the HomeUIStatePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(HomeUIStatus status, List<Todo> todos, String? errorMessage)?) → TResult?

Available on HomeUIState, provided by the HomeUIStatePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited