HomeUIStateNotifier class

Constructors

HomeUIStateNotifier()

Properties

hashCode int
The hash code for this object.
no setterinherited
ref → Ref
The Ref associated with this notifier.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state HomeUIState
The value currently exposed by this notifier.
getter/setter pairinherited
stateOrNull HomeUIState?
The value currently exposed by this Notifier.
no setterinherited

Methods

addTodo(String title) Future<void>
Side Effect Action: Uses sideEffectProvider for non-interactive feedback.
build() HomeUIState
Initialize a Notifier.
fetchTodos() Future<void>
Terminal Action: Affects the whole screen state
listenSelf(void listener(HomeUIState? previous, HomeUIState next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener
Listens to changes on the value exposed by this provider.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runBuild() → void
Executes Notifier.build.
inherited
toggleTodo(String id) Future<void>
toString() String
A string representation of this object.
inherited
updateShouldNotify(HomeUIState previous, HomeUIState next) bool
A method invoked when the state exposed by this Notifier changes. It compares the previous and new value, and return whether listeners should be notified.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited