AuthNotifier class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ref → Ref
-
The
Refassociated with this notifier.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ AuthState
-
The value currently exposed by this notifier.
getter/setter pairinherited
- stateOrNull → AuthState?
-
The value currently exposed by this
Notifier.no setterinherited - token → String?
-
no setter
Methods
-
build(
) → AuthState -
Initialize a
Notifier. -
listenSelf(
void listener(AuthState? previous, AuthState next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener -
Listens to changes on the value exposed by this provider.
inherited
-
login(
String email, String password) → Future< void> -
logout(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runBuild(
) → void -
Executes
Notifier.build.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
trySilentLogin(
) → Future< void> -
updateShouldNotify(
AuthState previous, AuthState next) → bool -
A method invoked when the state exposed by this
Notifierchanges. It compares the previous and new value, and return whether listeners should be notified.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited