AuthState class sealed
- Available extensions
- Annotations
-
- @freezed
Constructors
- AuthState.authenticated({required User user})
-
constfactory
- AuthState.initial()
-
constfactory
- AuthState.unauthenticated()
-
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> ({required TResult initial(_Initial value), required TResult unauthenticated(_Unauthenticated value), required TResult authenticated(_Authenticated value)}) → TResult -
Available on AuthState, provided by the AuthStatePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> ({TResult? initial(_Initial value)?, TResult? unauthenticated(_Unauthenticated value)?, TResult? authenticated(_Authenticated value)?}) → TResult? -
Available on AuthState, provided by the AuthStatePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({TResult initial(_Initial value)?, TResult unauthenticated(_Unauthenticated value)?, TResult authenticated(_Authenticated value)?, required TResult orElse()}) → TResult -
Available on AuthState, provided by the AuthStatePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({TResult initial()?, TResult unauthenticated()?, TResult authenticated(User user)?, required TResult orElse()}) → TResult -
Available on AuthState, provided by the AuthStatePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> ({required TResult initial(), required TResult unauthenticated(), required TResult authenticated(User user)}) → TResult -
Available on AuthState, provided by the AuthStatePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> ({TResult? initial()?, TResult? unauthenticated()?, TResult? authenticated(User user)?}) → TResult? -
Available on AuthState, provided by the AuthStatePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited