AppCarouselTheme class
- Inheritance
-
- Object
- ThemeExtension<
AppCarouselTheme> - AppCarouselTheme
Constructors
- AppCarouselTheme({Color? backgroundColor, double? elevation, ShapeBorder? shape})
Properties
- backgroundColor → Color?
-
final
- elevation → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → ShapeBorder?
-
final
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
{Color? backgroundColor, double? elevation, ShapeBorder? shape}) → AppCarouselTheme -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< AppCarouselTheme> ? other, double t) → AppCarouselTheme -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerpDouble(
double? a, double? b, double t) → double?