AppChipTheme class
- Inheritance
-
- Object
- ThemeExtension<
AppChipTheme> - AppChipTheme
Constructors
- AppChipTheme({ChipThemeData? primary, ChipThemeData? neutral, ChipThemeData? destructive})
Properties
- destructive → ChipThemeData?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- neutral → ChipThemeData?
-
final
- primary → ChipThemeData?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Object
-
The extension's type.
no setterinherited
Methods
-
copyWith(
{ChipThemeData? primary, ChipThemeData? neutral, ChipThemeData? destructive}) → AppChipTheme -
Creates a copy of this theme extension with the given fields
replaced by the non-null parameter values.
override
-
lerp(
covariant ThemeExtension< AppChipTheme> ? other, double t) → AppChipTheme -
Linearly interpolate with another ThemeExtension object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited