TodoNotifier class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ref → Ref
-
The
Refassociated with this notifier.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
↔ List<
Todo> -
The value currently exposed by this notifier.
getter/setter pairinherited
-
stateOrNull
→ List<
Todo> ? -
The value currently exposed by this
Notifier.no setterinherited
Methods
-
addTodo(
Todo todo) → void -
build(
) → List< Todo> -
Initialize a
Notifier. -
listenSelf(
void listener(List< Todo> ? previous, List<Todo> next), {void onError(Object error, StackTrace stackTrace)?}) → RemoveListener -
Listens to changes on the value exposed by this provider.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeTodo(
String id) → void -
runBuild(
) → void -
Executes
Notifier.build.inherited -
setTodos(
List< Todo> todos) → void -
toString(
) → String -
A string representation of this object.
inherited
-
updateShouldNotify(
List< Todo> previous, List<Todo> next) → bool -
A method invoked when the state exposed by this
Notifierchanges. It compares the previous and new value, and return whether listeners should be notified.inherited -
updateTodo(
Todo updatedTodo) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited